==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/tr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Parola en az %s karakter uzunluğunda olmalıdır",
    "Password needs to contain at least one lower and one upper case character." : "Parolada en az bir küçük ve bir büyük harf bulunmalıdır.",
    "Password needs to contain at least one numeric character." : "Parolada en az bir rakam bulunmalıdır.",
    "Password needs to contain at least one special character." : "Parolada en az bir simge karakteri bulunmalıdır.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Yazdığınız parola sık kullanılan 1.000.000 parola içinde. Lütfen eşsiz bir parola seçin.",
    "Password policy" : "Parola ilkesi",
    "Minimal length" : "En az uzunluk",
    "Forbid common passwords" : "Sık kullanılan parolalar kullanılamasın",
    "Enforce upper and lower case characters" : "Parolada büyük ve küçük harfler bulunsun",
    "Enforce numeric characters" : "Parolada rakam bulunsun",
    "Enforce special characters" : "Parolada simge karakterleri bulunsun",
    "Password need to be at least %s characters long" : "Parola en az %s karakter uzunluğunda olmalıdır",
    "Password need to contain at least one lower case character and one upper case character." : "Parolada en az bir küçük ve bir büyük harf bulunmalıdır.",
    "Password need to contain at least one numeric character." : "Parolada en az bir rakam bulunmalıdır.",
    "Password need to contain at least one special character." : "Parolada en az bir simge karakteri bulunmalıdır.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Yazdığınız parola sık kullanılan 1.000.000 parola içinde. Lütfen daha karmaşık bir parola seçin."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/tr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Parola en az %s karakter uzunluğunda olmalıdır",
    "Password needs to contain at least one lower and one upper case character." : "Parolada en az bir küçük ve bir büyük harf bulunmalıdır.",
    "Password needs to contain at least one numeric character." : "Parolada en az bir rakam bulunmalıdır.",
    "Password needs to contain at least one special character." : "Parolada en az bir simge karakteri bulunmalıdır.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Yazdığınız parola sık kullanılan 1.000.000 parola içinde. Lütfen eşsiz bir parola seçin.",
    "Password is present in compromised password list. Please choose a different password." : "Yazdığınız parola bilinen parolalar listesinde. Lütfen başka bir parola seçin.",
    "Password policy" : "Parola ilkesi",
    "Minimal length" : "En az uzunluk",
    "Forbid common passwords" : "Sık kullanılan parolalar kullanılamasın",
    "Enforce upper and lower case characters" : "Parolada büyük ve küçük harfler bulunsun",
    "Enforce numeric characters" : "Parolada rakam bulunsun",
    "Enforce special characters" : "Parolada simge karakterleri bulunsun",
    "Check password against the list of breached passwords from haveibeenpwnd.com" : "Parolalar haveibeenpwnd.com üzerindeki bilinen parolalar listesi ile denetlensin",
    "Password need to be at least %s characters long" : "Parola en az %s karakter uzunluğunda olmalıdır",
    "Password need to contain at least one lower case character and one upper case character." : "Parolada en az bir küçük ve bir büyük harf bulunmalıdır.",
    "Password need to contain at least one numeric character." : "Parolada en az bir rakam bulunmalıdır.",
    "Password need to contain at least one special character." : "Parolada en az bir simge karakteri bulunmalıdır.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Yazdığınız parola sık kullanılan 1.000.000 parola içinde. Lütfen daha karmaşık bir parola seçin."
},
"nplurals=2; plural=(n > 1);");
